@@ -10,6 +10,9 @@ class SourceTypes(str, Enum):
     thread = 'thread'
     comment = 'comment'
     community_summary = 'community_summary'
+    mobileapp_paid = 'mobileapp_paid'
+    mobileapp_in_progress = 'mobileapp_in_progress'
+    mobileapp_ready = 'mobileapp_ready'
 
 
 @dataclass
